Plugin: JS9Mef

### JS9 Multi-Extension FITS Files

The Extensions plugin allows you to display the HDU extensions in a multi-extension FITS file. Simply click on the desired extension to display it.

By default, the display (including the underlying raw data) of the new extension replaces the previous data in the same image. If, however, the Display each extension as a separate image checkbox is selected, each succeeding extension will be displayed as a separate image, so that you can view two or more extensions simultaneously. In this case, you can use the Blink extension to blink the extensions or the File->move image to menu option to move an extension to a existing display or new light window. In all cases, the raw data for that extension is available for browser-based analysis.

Note that some extensions are not available for display, including images of less than two dimensions, and binary tables not containing x and y columns. These extensions are marked as invalid by a strike through their description.

See the FITS Primer for information about HDUs and multi-extension FITS.